@@ -6,7 +6,7 @@ use v5.10;
 use overload '""' => sub { shift->as_string };
 
 # ABSTRACT: Simple asynchronous finger request
-our $VERSION = '0.05'; # VERSION
+our $VERSION = '0.06'; # VERSION
 
 
 sub new
@@ -68,11 +68,21 @@ AnyEvent::Finger::Request - Simple asynchronous finger request
 
 =head1 VERSION
 
-version 0.05
+version 0.06
+
+=head1 SYNOPSIS
+
+ my $request = AnyEvent::Finger::Request->new('foo@localhost');
+
+=head1 DESCRIPTION
+
+This class represents finger request.  It is passed into
+L<AnyEvent::Finger::Server> when a finger request is made.
+See the documentation on that class for more details.
 
 =head1 CONSTRUCTOR
 
- my $request = AnyEvent::Finger::Request->new("foo@localhost");
+=head2 AnyEvent::Finger::Request->new( $address )
 
 The constructor takes a string which is the raw finger request.
 
