@@ -6,7 +6,7 @@ use v5.10;
 use overload '""' => sub { shift->as_string };
 
 # ABSTRACT: Simple asynchronous finger transaction
-our $VERSION = '0.05'; # VERSION
+our $VERSION = '0.06'; # VERSION
 
 
 sub res { shift->{res} }
@@ -31,7 +31,15 @@ AnyEvent::Finger::Transaction - Simple asynchronous finger transaction
 
 =head1 VERSION
 
-version 0.05
+version 0.06
+
+=head1 DESCRIPTION
+
+This class is a container for response and request objects
+which is used when a finger request comes into 
+L<AnyEvent::Finger::Server> server instance.  It also provides
+information about the connection (the remote, local ports and
+the remote client's address).
 
 =head1 METHODS
 
